plone_inline_editing_no_kbd
open | /ksstestportal/kssfolder/documentitem |
waitForText | parent-fieldname-title | KssDocument
click | parent-fieldname-title |
waitForElementPresent | title |
type | title | Kss Rocks!
click | kss-save |
waitForText | parent-fieldname-title | Kss Rocks!
open | /ksstestportal/kssfolder/documentitem |
waitForText | parent-fieldname-title | Kss Rocks!
assertText | parent-fieldname-title | Kss Rocks!
click | parent-fieldname-title |
waitForElementPresent | title |
type | title | Not going to submit this
click | kss-cancel |
waitForText | parent-fieldname-title | Kss Rocks!
assertText | parent-fieldname-title | Kss Rocks!
click | parent-fieldname-title |
waitForElementPresent | title |
type | title | KssDocument
click | css=input[name='kss-save'] |
waitForText | parent-fieldname-title | KssDocument